@@ -56,3 +56,15 @@ class AgentUpdateFields(BaseModel):
     name: Optional[str] = None
     assistant_id: Optional[str] = None
     profile_id: Optional[str] = None
+
+
+
+def create_agent(data: dict) -> Agent:
+    """Create agent instance from data."""
+    agent_type = data.get('type')
+    if agent_type == 'human':
+        return HumanAgent(**data)
+    elif agent_type == 'ai':
+        return AIAgent(**data)
+    else:
+        raise ValueError(f"Unknown agent type: {agent_type}")
\ No newline at end of file
