@@ -1,7 +1,7 @@
 """
 Antonnia SDK API Types
 
-Type definitions for all API data models including sessions, messages.
+Type definitions for all API data models including sessions, messages, agents.
 """
 from .messages_requests import (
     MessagesSendRequest,
@@ -18,6 +18,11 @@ from .sessions_requests import (
     SessionsReplyRequest,
     SessionScheduleRequest,
 )
+from .agents_requests import (
+    AgentsCreateRequest,
+    AgentsUpdateRequest,
+    AgentsSearchRequest,
+)
 
 __all__ = [
     # Sessions
@@ -33,4 +38,8 @@ __all__ = [
     "MessagesCreateRequest",
     "MessagesUpdateRequest",
     "MessagesSearchRequest",
+    # Agents
+    "AgentsCreateRequest",
+    "AgentsUpdateRequest",
+    "AgentsSearchRequest",
 ] 
